<?php

namespace Teknisa\DF\Factories;

use Doctrine\ORM\EntityManager;

class InformacoesDePagamentoFactory{
    private $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }
    
    public function saveInfoPagamento($filial, $lancamento, $row) {
        
        $codigo = $this->getNewCode($filial, $lancamento);
        if(empty($codigo)){
            $codigo = '001';
        }
        $informacoes = $this->getInfoNota($filial, $lancamento);
        $this->salvaInformacoes($filial, $lancamento, $codigo, $informacoes, $row);
    }
    
    public function deleteInfoPagamento($filial, $lancamento, $row) {
        
        $codigo = $row['NRSEQINFOPAGANFE'];
        $informacoes = $this->getInfoNota($filial, $lancamento);
        $this->excluiInformacoes($filial, $lancamento, $codigo);
    }
    public function editaInfoPagamento($filial, $lancamento, $row) {
        
        $codigo = $row['NRSEQINFOPAGANFE'];
        $informacoes = $this->getInfoNota($filial, $lancamento);
        $this->atualizaInformacoes($filial, $lancamento, $codigo,$informacoes,$row);
    }
    
    public function atualizaInformacoes($filial, $lancamento, $codigo,$informacoes,$row){
        $idAtivo = $informacoes[0]['IDATIVO'];
        $dtInclusao = $informacoes[0]['DTINCLUSAO'];
        $dtUltatu = $informacoes[0]['DTULTATU'];
        $nrorgInclusao = $informacoes[0]['NRORGINCLUSAO'];
        $cdoperinclusao = $informacoes[0]['CDOPERINCLUSAO'];
        $nrorgUltatu = $informacoes[0]['NRORGULTATU'];
        $cdoperUltatu = $informacoes[0]['CDOPERULTATU'];
        $nrorg =  $informacoes[0]['NRORG'];
        
        var_dump($row['VRPAGAMENTO']);
        
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $sql = "UPDATE INFOPAGANFE 
                    SET 
                    IDATIVO = :IDATIVO,
                    DTINCLUSAO = :DTINCLUSAO,
                    DTULTATU = :DTULTATU,
                    NRORGINCLUSAO = :NRORGINCLUSAO,
                    CDOPERINCLUSAO = :CDOPERINCLUSAO,
                    NRORGULTATU = :NRORGULTATU,
                    CDOPERULTATU = :CDOPERULTATU,
                    IDTPMEIOPAGA = :IDTPMEIOPAGA,
                    VRPAGAMENTO = :VRPAGAMENTO,
                    IDTPINTPAGACARD = :IDTPINTPAGACARD,
                    NRINSJURCREDCARD = :NRINSJURCREDCARD,
                    IDTPBANDCARD = :IDTPBANDCARD,
                    NRAUTOOPERACARD = :NRAUTOOPERACARD,
                    IDTPFORMAPAGA = :IDTPFORMAPAGA,
                    IDGERADOINFOAUTO = :IDGERADOINFOAUTO,
                    NRORG = :NRORG 
                    WHERE  CDFILIAL = :CDFILIAL
                        AND NRLANCTONF = :NRLANCTONF
                        AND NRSEQINFOPAGANFE = :NRSEQINFOPAGANFE";
            
            $params = array(
                "CDFILIAL"              =>  $filial,
                "NRLANCTONF"            =>  $lancamento,
                "NRSEQINFOPAGANFE"      =>  $codigo,
                "IDATIVO"               =>  $idAtivo,
                "DTINCLUSAO"            =>  $dtInclusao,
                "DTULTATU"              =>  $dtUltatu,
                "NRORGINCLUSAO"         =>  $nrorgInclusao,
                "CDOPERINCLUSAO"        =>  $cdoperinclusao,
                "NRORGULTATU"           =>  $nrorgUltatu,
                "CDOPERULTATU"          =>  $cdoperUltatu,
                "IDTPMEIOPAGA"          =>  $row['IDTPMEIOPAGA'],
                "VRPAGAMENTO"           =>  $row['VRPAGAMENTO'],
                "IDTPINTPAGACARD"       =>  $row['IDTPINTPAGACARD'],
                "NRINSJURCREDCARD"      =>  $row['NRINSJURCREDCARD'],
                "IDTPBANDCARD"          =>  $row['IDTPBANDCARD'],
                "NRAUTOOPERACARD"       =>  $row['NRAUTOOPERACARD'],
                "IDTPFORMAPAGA"         =>  $row['IDTPFORMAPAGA'],
                "IDGERADOINFOAUTO"      =>  'N',
                "NRORG"                 =>  $nrorg
            );
        
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->execute($params);
            
            $connection->commit();
        }
        catch(\Exception $e) {
            $connection->rollback();
            $erros[] = $e->getMessage();
            var_dump($e->getMessage());
        }
    }
    
    public function getNewCode($filial, $lancamento){
        $sql = "SELECT LPAD((MAX(I.NRSEQINFOPAGANFE) + 1), 3, '0') AS CODIGO 
            FROM  INFOPAGANFE I 
            WHERE CDFILIAL = :P_CDFILIAL
            AND NRLANCTONF = :P_NRLANCTONF";
                
        $params = array(
            "P_NRLANCTONF"        => $lancamento,
            "P_CDFILIAL"          => $filial
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetch()["CODIGO"];
    }
    
    public function getInfoNota($filial, $lancamento) {
         $sql = "SELECT IDATIVO,
                        DTINCLUSAO,
                        DTULTATU,
                        NRORGINCLUSAO,
                        CDOPERINCLUSAO,
                        NRORGULTATU,
                        CDOPERULTATU,
                        NRORG
                FROM NOTAFISCAL
                WHERE CDFILIAL = :P_CDFILIAL
                AND NRLANCTONF = :P_NRLANCTONF";
                
        $params = array(
            "P_NRLANCTONF"        => $lancamento,
            "P_CDFILIAL"          => $filial
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
         
    }
    
    public function salvaInformacoes($filial, $lancamento,$codigo,$informacoes, $row){
        $idAtivo = $informacoes[0]['IDATIVO'];
        $dtInclusao = $informacoes[0]['DTINCLUSAO'];
        $dtUltatu = $informacoes[0]['DTULTATU'];
        $nrorgInclusao = $informacoes[0]['NRORGINCLUSAO'];
        $cdoperinclusao = $informacoes[0]['CDOPERINCLUSAO'];
        $nrorgUltatu = $informacoes[0]['NRORGULTATU'];
        $cdoperUltatu = $informacoes[0]['CDOPERULTATU'];
        $nrorg =  $informacoes[0]['NRORG'];
        
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $sql = "INSERT INTO INFOPAGANFE (
                CDFILIAL,
                IDATIVO,
                DTINCLUSAO,
                DTULTATU,
                NRORGINCLUSAO,
                CDOPERINCLUSAO,
                NRORGULTATU,
                CDOPERULTATU,
                NRLANCTONF,
                NRSEQINFOPAGANFE,
                IDTPMEIOPAGA,
                VRPAGAMENTO,
                IDTPINTPAGACARD,
                NRINSJURCREDCARD,
                IDTPBANDCARD,
                NRAUTOOPERACARD,
                IDTPFORMAPAGA,
                IDGERADOINFOAUTO,
                NRORG
            ) VALUES (
                :P_CDFILIAL,
                :P_IDATIVO,
                :P_DTINCLUSAO,
                :P_DTULTATU,
                :P_NRORGINCLUSAO,
                :P_CDOPERINCLUSAO,
                :P_NRORGULTATU,
                :P_CDOPERULTATU,
                :P_NRLANCTONF,
                :P_NRSEQINFOPAGANFE,
                :P_IDTPMEIOPAGA,
                :P_VRPAGAMENTO,
                :P_IDTPINTPAGACARD,
                :P_NRINSJURCREDCARD,
                :P_IDTPBANDCARD,
                :P_NRAUTOOPERACARD,
                :P_IDTPFORMAPAGA,
                :P_IDGERADOINFOAUTO,
                :P_NRORG
            )";
            
            $params = array(
                "P_CDFILIAL"            =>  $filial,
                "P_NRLANCTONF"          =>  $lancamento,
                "P_IDATIVO"             =>  $idAtivo,
                "P_DTINCLUSAO"          =>  $dtInclusao,
                "P_DTULTATU"            =>  $dtUltatu,
                "P_NRORGINCLUSAO"       =>  $nrorgInclusao,
                "P_CDOPERINCLUSAO"      =>  $cdoperinclusao,
                "P_NRORGULTATU"         =>  $nrorgUltatu,
                "P_CDOPERULTATU"        =>  $cdoperUltatu,
                "P_NRSEQINFOPAGANFE"    =>  $codigo,
                "P_IDTPMEIOPAGA"        =>  $row['IDTPMEIOPAGA'],
                "P_VRPAGAMENTO"         =>  $row['VRPAGAMENTO'],
                "P_IDTPINTPAGACARD"     =>  $row['IDTPINTPAGACARD'],
                "P_NRINSJURCREDCARD"    =>  $row['NRINSJURCREDCARD'],
                "P_IDTPBANDCARD"        =>  $row['IDTPBANDCARD'],
                "P_NRAUTOOPERACARD"     =>  $row['NRAUTOOPERACARD'],
                "P_IDTPFORMAPAGA"       =>  $row['IDTPFORMAPAGA'],
                "P_IDGERADOINFOAUTO"    =>  'N',
                "P_NRORG"               =>  $nrorg 
            );
        
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->execute($params);
            
            $connection->commit();
        }
        catch(\Exception $e) {
            $connection->rollback();
            $erros[] = $e->getMessage();
        }
    }
    
    public function excluiInformacoes($filial, $lancamento, $codigo) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $sql = "DELETE FROM INFOPAGANFE 
                        WHERE CDFILIAL = :P_CDFILIAL 
                        AND NRLANCTONF = :P_NRLANCTONF 
                        AND NRSEQINFOPAGANFE = :P_NRSEQINFOPAGANFE";
            
            $params = array(
                "P_CDFILIAL"            =>  $filial,
                "P_NRLANCTONF"          =>  $lancamento,
                "P_NRSEQINFOPAGANFE"    =>  $codigo
            );
        
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->execute($params);
            
            $connection->commit();
        }
        catch(\Exception $e) {
            $connection->rollback();
            $erros[] = $e->getMessage();
            var_dump($e->getMessage());
        }
      
    }
}

