<?php

namespace Teknisa\DF\Modules\Entrada\Services;

use Teknisa\DF\Modules\Entrada\Factories\Dfe47000LiberacaoParaFinanceiroFactory;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource;
use Teknisa\DF\Modules\Entrada\Services\ManifestacaoDestinatarioService;

class Dfe47000LiberacaoParaFinanceiroService {
    
    protected $Dfe52000Factory;
    protected $Nrorg;
    protected $erros = array();
    protected $titulosSucesso = 0;

    public function __construct(Dfe47000LiberacaoParaFinanceiroFactory $dfe47000LiberacaoParaFinanceiroFactory, $environment, ManifestacaoDestinatarioService $manifestacaoDestinatarioService) {
        $this->dfe47000LiberacaoParaFinanceiroFactory = $dfe47000LiberacaoParaFinanceiroFactory;
        $this->nrorg        = $environment->getNrOrg();
        $this->filialLogada = $environment->getCdFilial();
        $this->environment  = $environment;
        $this->manifestacaoDestinatarioService = $manifestacaoDestinatarioService;
    }

    public function getFilter() {
        try {
            $dados = $this->dfe47000LiberacaoParaFinanceiroFactory->getDadosFilter($this->filialLogada);
            $row   = array( "CDEMPRESA" => $dados["CDEMPRESA"],
                            "NMEMPRESA" => $dados["NMEMPRESA"],
                            "DTENTRSAID" => $this->getDate($dados["DTPROCESSA"]));
        }
        catch(\Exception $e) {
             $row   = array("CDEMPRESA" => "",
                            "NMEMPRESA" => "",
                            "DTENTRSAID" => $this->getDate());
        }
        $row["TCDTIPOOPER"]     = "T";
        $row["TCDSERIEENTR"]    = "T";
        $row["TCDFILIORIG"]     = "T";
        $row["ERRO"]            = "T";
        $row["IDBLOQNFFIN"]     = "T";
        return $row;
    }
    
    public function getDate($dtProcessa = '') {
        if(!$dtProcessa) $dtProcessa = 'now';
        else $dtProcessa = str_replace("/", "-", substr($dtProcessa, 0, 10));
  
        $date   = new \DateTime($dtProcessa);
        $date->modify('last day of this month');
        $mes    = $date->format('m');
        $ano    = $date->format("Y"); 
        $date   = array("start" => "01"."/$mes/".$ano, "end" => $date->format('d/m/Y'));
        return $date;
    }
    
     /**
    *   Bloqueia ou libera o titulo de acordo como o parametro $mode
    *   
    *   @param array   $det                 - Dados Completos do produto (impostos, valores, etc)
    *   @param char    $mode                - B (Bloquear) - L (Liberar)
    */
    public function setAprovacao($notas, $mode) {
        $configs        = array();
        $paramManifesta = $this->dfe47000LiberacaoParaFinanceiroFactory->getParamManifesta(); 
        $idManifestacao = ($paramManifesta["IDCIENCIAEMISS"] == '4') ? 4 : ($paramManifesta["IDCONFIRMAEMISS"]) ? 1 : 0;
        $titulosSucesso = 0;
        foreach ($notas as $nota) {
            try {
                if($mode == 'B') {
                    // Rotina para verificação das contas a pagar já geradas (se estão baixadas, etc)
                    $this->dfe47000LiberacaoParaFinanceiroFactory->cancelaVencimento($nota["CDFILIAL"], $nota["NRLANCTONF"]);
                }
                
                if($mode == 'L') {
                    $data = date("d/m/Y H:i:s");
                    $this->dfe47000LiberacaoParaFinanceiroFactory->updateIdBloqueado('L', $this->environment->getCdOperador(), '', $data, $nota["CDFILIAL"], $nota["NRLANCTONF"]);
                  
                    // Manifesta a nota de acordo com a parametrização
                    
                    if($idManifestacao != 0) {
                        try {
                            if(!isset($configs[$nota["CDEMPRESA"]])) {
                                $config     = $this->manifestacaoDestinatarioService->montaConfigManifestacao($nota["CDEMPRESA"], $this->environment->getNrOrgTrab(), $nota["CDINSCESTA"], '', true);
                                $configs[$nota["CDEMPRESA"]] = $config;
                            }
                            else {
                                $config = $configs[$nota["CDEMPRESA"]];
                            }
                            $retorno = $this->manifestacaoDestinatarioService->manifestarNfe(array($nota), $config, $idManifestacao);
                        }
                        catch(\Exception $e) {}
                    }
                }
                else {
                    $this->dfe47000LiberacaoParaFinanceiroFactory->updateIdBloqueado('B', $this->environment->getCdOperador(), '', '', $nota["CDFILIAL"], $nota["NRLANCTONF"]);
                }
                $titulosSucesso++;
                
            }
            catch(\Exception $e) {
                array_push($this->erros, array("NRNOTAFISC"     => $nota["NRNOTAFISC"],
                                         "DTEMISSAO"            => $nota["DTEMISSAO"],
                                         "VRNOTAFISC"           => $nota["VRNOTAFISC"],
                                         "DSERRO"               => $e->getMessage()));
            }
        }
        return array("SUCESSOS" => $titulosSucesso, "ERROS" => $this->erros);
    }
}